Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1277)

Unified Diff: net/quic/congestion_control/quic_send_scheduler.cc

Issue 11820005: Largest received -> largest observed. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: rebase Created 7 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | net/quic/congestion_control/quic_send_scheduler_test.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: net/quic/congestion_control/quic_send_scheduler.cc
diff --git a/net/quic/congestion_control/quic_send_scheduler.cc b/net/quic/congestion_control/quic_send_scheduler.cc
index 17c4a2fb28b8d68f4790005f14e09b96551b111e..7b30ee0140db0f4ebb02a3fd06cec0f21ee3070c 100644
--- a/net/quic/congestion_control/quic_send_scheduler.cc
+++ b/net/quic/congestion_control/quic_send_scheduler.cc
@@ -86,7 +86,7 @@ void QuicSendScheduler::OnIncomingQuicCongestionFeedbackFrame(
void QuicSendScheduler::OnIncomingAckFrame(const QuicAckFrame& ack_frame) {
// We want to.
// * Get all packets lower(including) than largest_received
// from pending_packets_.
// * Remove all missing packets.
// * Send each ACK in the list to send_algorithm_.
@@ -96,7 +96,7 @@ void QuicSendScheduler::OnIncomingAckFrame(const QuicAckFrame& ack_frame) {
PendingPacketsMap::iterator it, it_upper;
it = pending_packets_.begin();
it_upper = pending_packets_.upper_bound(
- ack_frame.received_info.largest_received);
+ ack_frame.received_info.largest_observed);
while (it != it_upper) {
QuicPacketSequenceNumber sequence_number = it->first;
« no previous file with comments | « no previous file | net/quic/congestion_control/quic_send_scheduler_test.cc » ('j') | no next file with comments »
@@ -86,7 +86,7 @@ void QuicSendScheduler::OnIncomingQuicCongestionFeedbackFrame(
void QuicSendScheduler::OnIncomingAckFrame(const QuicAckFrame& ack_frame) {
// We want to.
- // * Get all packets lower(including) than largest_received
+ // * Get all packets lower(including) than largest_observed
// from pending_packets_.
// * Remove all missing packets.

Powered by Google App Engine
This is Rietveld 408576698